import request from '@/utils/request'

export function fetchList(query) {
  return request({
    url: '/ncjtEntranceGuard/getGroupList',
    method: 'get',
    params: query
  })
}

export function fetchDataList(query) {
  return request({
    url: '/ncjtEntranceGuard/getUserByGroupId',
    method: 'get',
    params: query
  })
}

export function createGroup(data) {
  return request({
    url: '/vue-element-admin/article/create',
    method: 'post',
    data
  })
}

export function updateGroup(data) {
  return request({
    url: '/vue-element-admin/article/update',
    method: 'post',
    data
  })
}

// export function fetchGroup(id) {
//   return request({
//     url: '/vue-element-admin/article/detail',
//     method: 'get',
//     params: { id }
//   })
// }

// export function fetchPv(pv) {
//   return request({
//     url: '/vue-element-admin/article/pv',
//     method: 'get',
//     params: { pv }
//   })
// }